@@ -531,42 +531,69 @@ class TestManagerSystem(Component):
                 
                 tcatId = req.args.get('tcatId')
                 planid = req.args.get('planid')
-                self.env.log.debug("About to add test case %s to test plan %s" % (tcId, planid))
+		
+                self.env.log.debug("About to add test case %s to test plans %s" % (tcId, planid))
 
+                tc = None
                 tp = None
                 tcip = None
                 page_name = None
+
                 try:
                     tc = TestCase(self.env, tcId)
-                    tp = TestPlan(self.env, planid, tcatId)
-                    
                     page_name = tc['page_name']
-
-                    # Add the test case to the plan, i.e. add a testcaseinplan object
-                    tcip = TestCaseInPlan(self.env, tcId, planid)
-                    if not tcip.exists:
-                        tcip['page_name'] = page_name
-                        if tp['freeze_tc_versions']:
-                            # Set the wiki page version to the current latest version
-                            tcip['page_version'] = tc.wikipage.version
-                        tcip.set_status(self.get_default_tc_status(), author)
-                        tcip.insert()
-                        add_notice(req, _("The Test Case was successfully added to the plan."))
-                    else:
-                        add_warning(req, _("The Test Case was already contained in the specified Test Plan."))
-                    
                 except:
                     self.env.log.error("Error adding test case to plan!")
                     self.env.log.error(formatExceptionInfo())
-                    # Back to the test case
-                    add_warning(req, _("An error occurred while adding the test case into the plan."))
-                    req.redirect(req.href.wiki(page_name))
+                    add_warning(req, _("An error occurred while adding the test case into the selected Test Plans."))
+                    req.redirect(req.href.wiki("TC"))
+
+                tplans = planid.split(",")
+                add_ok = 0
+                redirect_url = req.href.wiki("TC")
+
+                for curr_planid in tplans:
+                    tp = None
+                    
+                    try:
+                        tp = TestPlan(self.env, curr_planid, tcatId)
+
+                        # Add the test case to the plan, i.e. add a testcaseinplan object
+                        tcip = TestCaseInPlan(self.env, tcId, curr_planid)
+                        if not tcip.exists:
+                            tcip['page_name'] = page_name
+                            if tp['freeze_tc_versions']:
+                                # Set the wiki page version to the current latest version
+                                tcip['page_version'] = tc.wikipage.version
+                            tcip.set_status(self.get_default_tc_status(), author)
+                            tcip.insert()
+                            
+                            add_ok += 1
+                            
+                            if tp['freeze_tc_versions']:
+                                redirect_url = req.href.wiki(page_name, planid=curr_planid, version=tcip['page_version'])
+                            else:
+                                redirect_url = req.href.wiki(page_name, planid=curr_planid)
+
+                        else:
+                            add_warning(req, _("The Test Case was already contained in the '%s' Test Plan." % (tp['name'],)))
+                        
+                    except:
+                        self.env.log.error("Error adding test case to plan!")
+                        self.env.log.error(formatExceptionInfo())
+                        if tp is not None:
+                            add_warning(req, _("An error occurred while adding the test case into the '%s' Test Plan." % (tp['name'],)))
+                        else:
+                            add_warning(req, _("An error occurred while adding the test case into the Test Plan with id '%s'." % (curr_planid,)))
+
+                if add_ok > 0:
+                    add_notice(req, _("The Test Case was successfully added to %s Test Plans." % (add_ok,)))
+
+                    # Redirect to test case in the last selected test plan
+                    req.redirect(redirect_url)
+                    
+                req.redirect(req.href.wiki(page_name))
 
-                # Redirect to test case in plan
-                if tp['freeze_tc_versions']:
-                    req.redirect(req.href.wiki(page_name, planid=planid, version=tcip['page_version']))
-                else:
-                    req.redirect(req.href.wiki(page_name, planid=planid))
                 
             elif object_type == 'testcase':
                 req.perm.require('TEST_MODIFY')
