@@ -143,10 +143,19 @@ function addTestCaseToTestplanDialog() {
 function addTestCaseToPlan(tcId, tcatId) {
 	(function($) {
 		$(function() {
-			var planid = $("input[name='selected_planid']:checked").val();
+			var planids = $("input[name='selected_planid']:checked");
 			
-			if (planid && planid != '') {
-				var url = baseLocation+"/testcreate?type=testcaseinplan&tcatId="+tcatId+"&tcId="+tcId+"&planid="+planid;
+			if (planids && planids.length > 0) {
+				var planIdList = "";
+				
+				for (var i=0; i<planids.length; i++) {
+					planIdList += $(planids[i]).val();
+					if (i < planids.length - 1) {
+						planIdList += ",";
+					}
+				}
+
+				var url = baseLocation+"/testcreate?type=testcaseinplan&tcatId="+tcatId+"&tcId="+tcId+"&planid="+planIdList;
 				window.location = url;
 			}
 		});
