@@ -920,7 +920,7 @@ class WikiTestManagerInterface(Component):
             if not tp['contains_all']:
                 result += '<tr>'
 
-                result += '<td><input type="radio" name="selected_planid" value="'+tp['id']+'" /></td>'
+                result += '<td><input type="checkbox" name="selected_planid" value="'+tp['id']+'" /></td>'
                 result += '<td>'+tp['name']+'</td>'
                 result += '<td>'+html_escape(tp['author'])+'</td>'
                 result += '<td>'+format_datetime(tp['time'])+'</td>'
